@@ -14,24 +14,38 @@
 #' @param time_res a character string with the desired time resolution. Suitable options are:
 #' \itemize{
 #' \item{"monthly",}
-#' \item{"yearly".}
+#' \item{"yearly",}
+#' \item{"daily".}
+#' }
+#' @param variable a character string for the variable. Suitable options are:
+#' \itemize{
+#' \item{"e" for actual evapotranspiration,}
+#' \item{"pet" for potential evapotranspiration.}
 #' }
 #' @return No return value, called to download the data set.
 #' @keywords internal
 
-download_fldas <- function(path = "", domain = "raw", time_res = "monthly"){
+download_fldas <- function(path = "", domain = "raw", time_res = "monthly", variable = "e"){
   old_options <- options()
   on.exit(options(old_options))
   options(timeout = 6000)
-  if (domain == "raw" | domain == "land"){
+  
+  if (domain == "raw" | domain == "land") {
     domain <- "land"
   } else {
     warning(paste0('The ', domain, ' domain is not available'))
   }
-  zenodo_base <- "https://zenodo.org/records/10123598/files/"
+  
+  if (!(variable %in% c("e", "pet"))) {
+    stop("Unsupported variable specified. Use 'e' for actual evapotranspiration or 'pet' for potential evapotranspiration.")
+  }
+  
+  zenodo_base <- "https://zenodo.org/records/14622177/files/"
   zenodo_end <- "?download=1"
-  file_name <- paste0("fldas_e_mm_", domain, "_198201_202309_025_", time_res, ".nc")
+  file_name <- paste0("fldas_", variable, "_mm_", domain, "_198201_202212_025_", time_res, ".nc")
   file_url <- paste0(zenodo_base, file_name, zenodo_end)
+  
   file_destination <- paste(path, file_name, sep = "/")
+  
   try(download.file(file_url, file_destination, mode = "wb"), silent = TRUE)
 }
