@@ -14,24 +14,54 @@
 #' @param time_res a character string with the desired time resolution. Suitable options are:
 #' \itemize{
 #' \item{"monthly",}
-#' \item{"yearly".}
+#' \item{"yearly",}
+#' \item{"daily".}
+#' }
+#' @param variable a character string for the variable. Suitable options are:
+#' \itemize{
+#' \item{"e" for actual evapotranspiration,}
+#' \item{"pet" for potential evapotranspiration.}
+#' }
+#' @param version an optional character string for the version. Suitable options are:
+#' \itemize{
+#' \item{"v3-7a" for version 3.7a,}
+#' \item{"v4-1a" for version 4.1a,}
+#' \item{"" for default version v3-7a.}
 #' }
 #' @return No return value, called to download the data set.
 #' @keywords internal
 
-download_gleam <- function(path = "", domain = "raw", time_res = "monthly"){
+download_gleam <- function(path = "", domain = "raw", time_res = "monthly", variable = "e", version = ""){
   old_options <- options()
   on.exit(options(old_options))
   options(timeout = 6000)
-  if (domain == "raw" | domain == "land"){
+  
+  if (version == "") {
+    version <- "v3-7a"
+  }
+  
+  if (domain == "raw" | domain == "land") {
     domain <- "land"
   } else {
     warning(paste0('The ', domain, ' domain is not available'))
   }
-  zenodo_base <- "https://zenodo.org/records/10123598/files/"
+  
+  if (!(variable %in% c("e", "pet"))) {
+    stop("Unsupported variable specified. Use 'e' for actual evapotranspiration or 'pet' for potential evapotranspiration.")
+  }
+  
+  zenodo_base <- "https://zenodo.org/records/14622177/files/"
   zenodo_end <- "?download=1"
-  file_name <- paste0("gleam_e_mm_", domain, "_198001_202112_025_", time_res, ".nc")
+  
+  if (version == "v3-7a") {
+    file_name <- paste0("gleam-", version, "_", variable, "_mm_", domain, "_198001_202112_025_", time_res, ".nc")
+  } else if (version == "v4-1a") {
+    file_name <- paste0("gleam-", version, "_", variable, "_mm_", domain, "_198001_202312_025_", time_res, ".nc")
+  } else {
+    stop("Unsupported version specified")
+  }
+  
   file_url <- paste0(zenodo_base, file_name, zenodo_end)
   file_destination <- paste(path, file_name, sep = "/")
   try(download.file(file_url, file_destination, mode = "wb"), silent = TRUE)
-}
\ No newline at end of file
+}
